from ._version import version as version
from ._version import version_tuple as version_tuple
from ._version import __version__ as __version__
from ._version import __version_tuple__ as __version_tuple__
